@@ -1,10 +1,11 @@
 const webcam = {
   html: `
-    <div class="webcam_box"></div>
+    <div class="interface_box">
+      <div class="webcam_box"></div>
+    </div>
   `,
   init: function(opts) {
     var io = this;
-//    this.target.find(".webcam_box").width(this.target.find(".webcam_box").width);
     let w = this.target.find(".webcam_box").width();
     let h = this.target.find(".webcam_box").height();
     let RATIO = 4/3;
